@@ -116,7 +116,11 @@ QStringList XdgBaseDirs::systemPathList( const char *resource )
     if ( instance()->mDataDirs.isEmpty() ) {
       QStringList dataDirs = instance()->systemPathList( "XDG_DATA_DIRS", "/usr/local/share:/usr/share" );
 
+#ifdef Q_OS_WIN
+      const QString prefixDataDir = QLatin1String( AKONADIPREFIX "/" AKONADIDATA );
+#else
       const QString prefixDataDir = QLatin1String( AKONADIDATA );
+#endif
       if ( !dataDirs.contains( prefixDataDir ) ) {
         dataDirs << prefixDataDir;
       }
@@ -142,7 +146,11 @@ QStringList XdgBaseDirs::systemPathList( const char *resource )
     if ( instance()->mConfigDirs.isEmpty() ) {
       QStringList configDirs = instance()->systemPathList( "XDG_CONFIG_DIRS", "/etc/xdg" );
 
+#ifdef Q_OS_WIN
+      const QString prefixConfigDir = QLatin1String( AKONADIPREFIX "/" AKONADICONFIG );
+#else
       const QString prefixConfigDir = QLatin1String( AKONADICONFIG );
+#endif
       if ( !configDirs.contains( prefixConfigDir ) ) {
         configDirs << prefixConfigDir;
       }
@@ -190,6 +198,11 @@ QString XdgBaseDirs::findExecutableFile( const QString &relPath, const QStringLi
 
     executableDirs += searchPath;
 
+#if defined(Q_OS_MAC) //krazy:exclude=cpp
+    executableDirs += QLatin1String(AKONADIBUNDLEPATH);
+#endif
+    qWarning( ) << "search paths: " << executableDirs;
+
     instance()->mExecutableDirs = executableDirs;
   }
 
@@ -201,9 +214,14 @@ QString XdgBaseDirs::findExecutableFile( const QString &relPath, const QStringLi
     QStringList::const_iterator it    = fullPathList.constBegin();
     QStringList::const_iterator endIt = fullPathList.constEnd();
     for ( ; it != endIt; ++it ) {
-      QFileInfo fileInfo(*it);
+      const QFileInfo fileInfo( *it );
 
-      if ( fileInfo.exists() && fileInfo.isFile() && fileInfo.isExecutable() ) {
+      // resolve symlinks, happens eg. with Maemo optify
+      if ( fileInfo.canonicalFilePath().isEmpty() )
+        continue;
+      const QFileInfo canonicalFileInfo( fileInfo.canonicalFilePath() );
+
+      if ( canonicalFileInfo.exists() && canonicalFileInfo.isFile() && canonicalFileInfo.isExecutable() ) {
         return *it;
       }
     }
