@@ -21,6 +21,7 @@
 
 #include "../../libs/xdgbasedirs_p.h"
 #include "akdebug.h"
+#include "utils.h"
 
 #include <QtCore/QDateTime>
 #include <QtCore/QDir>
@@ -55,6 +56,8 @@ bool DbConfigMysql::init( QSettings &settings )
   QString defaultServerPath;
   QString defaultCleanShutdownCommand;
 
+  const QString socketDirectory = Utils::preferredSocketDirectory( XdgBaseDirs::saveDir( "data", QLatin1String( "akonadi/db_misc" ) ) );
+
   defaultDbName = QLatin1String( "akonadi" );
   const bool defaultInternalServer = true;
 #ifdef MYSQLD_EXECUTABLE
@@ -77,7 +80,7 @@ bool DbConfigMysql::init( QSettings &settings )
 #ifndef Q_OS_WIN
     defaultCleanShutdownCommand = QString::fromLatin1( "%1 shutdown --socket=%2/mysql.socket" )
                                       .arg( mysqladminPath )
-                                      .arg( XdgBaseDirs::saveDir( "data", QLatin1String( "akonadi/db_misc" ) ) );
+                                      .arg( socketDirectory );
 #else
     defaultCleanShutdownCommand = QString::fromLatin1( "%1 shutdown --shared-memory" ).arg( mysqladminPath );
 #endif
@@ -86,14 +89,13 @@ bool DbConfigMysql::init( QSettings &settings )
   mMysqlInstallDbPath = XdgBaseDirs::findExecutableFile( QLatin1String( "mysql_install_db" ), mysqldSearchPath );
   akDebug() << "Found mysql_install_db: " << mMysqlInstallDbPath;
 
-  mMysqlUpgradeDBPath = XdgBaseDirs::findExecutableFile( QLatin1String( "mysql_upgrade" ), mysqldSearchPath );
-  akDebug() << "Found mysql_upgrade: " << mMysqlUpgradeDBPath;
+  mMysqlCheckPath = XdgBaseDirs::findExecutableFile( QLatin1String( "mysqlcheck" ), mysqldSearchPath );
+  akDebug() << "Found mysqlcheck: " << mMysqlCheckPath;
 
   mInternalServer = settings.value( QLatin1String( "QMYSQL/StartServer" ), defaultInternalServer ).toBool();
   if ( mInternalServer ) {
-    const QString miscDir = XdgBaseDirs::saveDir( "data", QLatin1String( "akonadi/db_misc" ) );
 #if !(defined Q_WS_WIN)
-    defaultOptions = QString::fromLatin1( "UNIX_SOCKET=%1/mysql.socket" ).arg( miscDir );
+    defaultOptions = QString::fromLatin1( "UNIX_SOCKET=%1/mysql.socket" ).arg( socketDirectory );
 #endif
   }
 
@@ -163,7 +165,7 @@ void DbConfigMysql::startInternalServer()
 
   const QString akDir   = XdgBaseDirs::saveDir( "data", QLatin1String( "akonadi/" ) );
   const QString dataDir = XdgBaseDirs::saveDir( "data", QLatin1String( "akonadi/db_data" ) );
-  const QString miscDir = XdgBaseDirs::saveDir( "data", QLatin1String( "akonadi/db_misc" ) );
+  const QString socketDirectory = Utils::preferredSocketDirectory( XdgBaseDirs::saveDir( "data", QLatin1String( "akonadi/db_misc" ) ) );
 
   // generate config file
   const QString globalConfig = XdgBaseDirs::findResourceFile( "config", QLatin1String( "akonadi/mysql-global.conf" ) );
@@ -212,12 +214,12 @@ void DbConfigMysql::startInternalServer()
   if ( akDir.isEmpty() )
     akFatal() << "Akonadi server was not able to create database log directory";
 
-  if ( miscDir.isEmpty() )
+  if ( socketDirectory.isEmpty() )
     akFatal() << "Akonadi server was not able to create database misc directory";
 
   // the socket path must not exceed 103 characters, so check for max dir length right away
-  if ( miscDir.length() >= 90 )
-      akFatal() << "MySQL cannot deal with a socket path this long. Path was: " << miscDir;
+  if ( socketDirectory.length() >= 90 )
+      akFatal() << "MySQL cannot deal with a socket path this long. Path was: " << socketDirectory;
 
   // move mysql error log file out of the way
   const QFileInfo errorLog( dataDir + QDir::separator() + QString::fromLatin1( "mysql.err" ) );
@@ -239,7 +241,7 @@ void DbConfigMysql::startInternalServer()
   if ( QDir( dataDir ).entryList( QDir::NoDotAndDotDot | QDir::AllEntries ).isEmpty() && !mMysqlInstallDbPath.isEmpty() ) {
     const QStringList arguments = QStringList() << QString::fromLatin1( "--force" ) << QString::fromLatin1( "--defaults-file=%1").arg(confFile) << QString::fromLatin1( "--datadir=%1/" ).arg( dataDir ); 
     QProcess::execute( mMysqlInstallDbPath, arguments );
-  } 
+  }
 
   // clear mysql ib_logfile's in case innodb_log_file_size option changed in last confUpdate
   if ( confUpdate ) {
@@ -252,7 +254,7 @@ void DbConfigMysql::startInternalServer()
   arguments << QString::fromLatin1( "--defaults-file=%1/mysql.conf" ).arg( akDir );
 #ifndef Q_WS_WIN
   arguments << QString::fromLatin1( "--datadir" ) << QString::fromLatin1( "%1/" ).arg( dataDir );
-  arguments << QString::fromLatin1( "--socket=%1/mysql.socket" ).arg( miscDir );
+  arguments << QString::fromLatin1( "--socket=%1/mysql.socket" ).arg( socketDirectory );
 #else
   arguments << QString::fromLatin1( "--datadir=%1/" ).arg( dataDir );
   arguments << QString::fromLatin1( "--shared-memory" );
@@ -267,11 +269,6 @@ void DbConfigMysql::startInternalServer()
     akFatal() << "process error:" << mDatabaseProcess->errorString();
   }
 
-  if ( !mMysqlUpgradeDBPath.isEmpty() ) {
-    const QStringList arguments = QStringList() << QString::fromLatin1( "--socket=%1/mysql.socket" ).arg( miscDir );
-    QProcess::execute( mMysqlUpgradeDBPath, arguments );
-  }
-
   const QLatin1String initCon( "initConnection" );
   {
     QSqlDatabase db = QSqlDatabase::addDatabase( QLatin1String( "QMYSQL" ), initCon );
@@ -298,6 +295,15 @@ void DbConfigMysql::startInternalServer()
     }
 
     if ( opened ) {
+
+      if ( !mMysqlCheckPath.isEmpty() ) {
+        const QStringList arguments = QStringList() << QLatin1String( "--check-upgrade" )
+                                                    << QLatin1String( "--all-databases" )
+                                                    << QLatin1String( "--auto-repair" )
+                                                    << QString::fromLatin1( "--socket=%1/mysql.socket" ).arg( socketDirectory );
+        QProcess::execute( mMysqlCheckPath, arguments );
+      }
+
       {
         QSqlQuery query( db );
         if ( !query.exec( QString::fromLatin1( "USE %1" ).arg( mDatabaseName ) ) ) {
